@@ -59,13 +59,17 @@ TCP_STATUSES = {
 }
 
 scputimes = namedtuple('scputimes', ['user', 'system', 'idle', 'iowait'])
+pcputimes = namedtuple('pcputimes',
+                       ['user', 'system', 'children_user', 'children_system'])
 svmem = namedtuple('svmem', ['total', 'available', 'percent', 'used', 'free'])
 pmem = namedtuple('pmem', ['rss', 'vms'])
+pfullmem = pmem
 pmmap_grouped = namedtuple('pmmap_grouped',
                            ['path', 'rss', 'anonymous', 'locked'])
 pmmap_ext = namedtuple(
     'pmmap_ext', 'addr perms ' + ' '.join(pmmap_grouped._fields))
 
+
 # set later from __init__.py
 NoSuchProcess = None
 ZombieProcess = None
@@ -165,6 +169,13 @@ def cpu_count_physical():
     return cext.cpu_count_phys()
 
 
+def cpu_stats():
+    ctx_switches, interrupts, syscalls, traps = cext.cpu_stats()
+    soft_interrupts = 0
+    return _common.scpustats(ctx_switches, interrupts, soft_interrupts,
+                             syscalls)
+
+
 def boot_time():
     """The system boot time expressed in seconds since the epoch."""
     return cext.boot_time()
@@ -256,6 +267,7 @@ def wrap_exceptions(fun):
     """Call callable into a try/except clause and translate ENOENT,
     EACCES and EPERM in NoSuchProcess or AccessDenied exceptions.
     """
+
     def wrapper(self, *args, **kwargs):
         try:
             return fun(self, *args, **kwargs)
@@ -347,7 +359,8 @@ class Process(object):
 
     @wrap_exceptions
     def ppid(self):
-        return cext.proc_basic_info(self.pid, self._procfs_path)[0]
+        self._ppid = cext.proc_basic_info(self.pid, self._procfs_path)[0]
+        return self._ppid
 
     @wrap_exceptions
     def uids(self):
@@ -363,8 +376,8 @@ class Process(object):
 
     @wrap_exceptions
     def cpu_times(self):
-        user, system = cext.proc_cpu_times(self.pid, self._procfs_path)
-        return _common.pcputimes(user, system)
+        times = cext.proc_cpu_times(self.pid, self._procfs_path)
+        return _common.pcputimes(*times)
 
     @wrap_exceptions
     def terminal(self):
